<?php
/**
 * Theme Framework functions and definitions
 *
 * Sets up the theme and provides some helper functions, which are used
 * in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook.
 *
 * For more information on hooks, actions, and filters, @link http://codex.wordpress.org/Plugin_API
 *
 * @package CMSSuperHeroes
 * @subpackage CMS Theme
 * @since 1.0.0
 */
 
// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) )
	$content_width = 870;
	
/**
 * CMS Theme setup.
 *
 * Sets up theme defaults and registers the various WordPress features that
 * CMS Theme supports.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To add a Visual Editor stylesheet.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links,
 * 	custom background, and post formats.
 * @uses register_nav_menu() To add support for navigation menus.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since 1.0.0
 */

function bo_setup() {

	// load language.
	load_theme_textdomain( 'wpbo' , get_template_directory() . '/languages' );

	// Adds title tag
	add_theme_support( "title-tag" );
	
	// Add woocommerce
	add_theme_support('woocommerce');
	
    //add_theme_support( 'wc-product-gallery-zoom' );
    add_theme_support( 'wc-product-gallery-lightbox' );
    //add_theme_support( 'wc-product-gallery-slider' );
	// Adds custom header
	add_theme_support( 'custom-header' );
	
	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// This theme supports a variety of post formats.
	add_theme_support( 'post-formats', array( 'video', 'audio' , 'gallery', 'quote') );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', esc_html__( 'Primary Menu', 'wpbo' ) );

	/*
	 * This theme supports custom background color and image,
	 * and here we also set up the default background color.
	 */
	add_theme_support( 'custom-background', array('default-color' => 'e6e6e6',) );

	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	  
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1170, 9999 ); // Unlimited height, soft crop
    
    update_option( 'thumbnail_size_w', 370); 	
    update_option( 'thumbnail_size_h', 370 ); 
    update_option( 'thumbnail_crop', 1);
    update_option( 'medium_size_w', 370);		
    update_option( 'medium_size_h', 240);
    update_option( 'medium_crop', 1);	
	update_option( 'large_size_w', 1170);  		
    update_option( 'large_size_h', 720);
    update_option( 'large_crop', 1);
    
    add_image_size('wpbo-420-290', 420, 290, true);	
    add_image_size('wpbo-630-435', 630, 435, true);	
    add_image_size('wpbo-370-270', 370, 270, true);
    add_image_size('wpbo-570-530', 570, 530, true);	
    add_image_size('wpbo-570-493', 570, 493, true);	

    
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'assets/css/editor-style.css' ) );
}

add_action( 'after_setup_theme', 'bo_setup' );


/* make shop image size*/
add_action('init', 'bo_change_default_woo_thumb_size');
function bo_change_default_woo_thumb_size(){
 register_activation_hook('woocommerce/woocommerce.php', 'bo_woocommerce_image_dimensions');
}
function bo_woocommerce_image_dimensions() {
    global $pagenow;
    $catalog = array(
        'width'     => '540',    
        'height'    => '500',   
        'crop'      => 1         
    );
    $single = array(
        'width'     => '450',    
        'height'    => '500',    
        'crop'      => 1         
    );
    $thumbnail = array(
        'width'     => '200',    
        'height'    => '220',    
        'crop'      => 1         
    );
  
    update_option( 'shop_catalog_image_size', $catalog );       
    update_option( 'shop_single_image_size', $single );         
    update_option( 'shop_thumbnail_image_size', $thumbnail );   
}
 
/**
 * support shortcodes
 * @return array
 */
function bo_shortcodes(){
	return array(
		'cms_carousel',
		'cms_grid',
		'cms_fancybox_single',
		'cms_counter_single',
		'cms_progressbar',
	);
}

/**
 * Add new elements for VC
 * 
 * @author FOX
 */
add_action('vc_before_init', 'bo_vc_before');

function bo_vc_before(){
	 
    if(!class_exists('CmsShortCode'))
        return ;
    
    require( get_template_directory() . '/inc/elements/zo_masonry.php' );
    require( get_template_directory() . '/inc/elements/cms_googlemap.php' );
    require( get_template_directory() . '/inc/elements/cms_testimonial_carousel.php' );
    require( get_template_directory() . '/inc/elements/cms_team.php' );
    require( get_template_directory() . '/inc/elements/cms_call_to_action.php' ); 
    require( get_template_directory() . '/inc/elements/cms_client_carousel.php' ); 
    require( get_template_directory() . '/inc/elements/cms_countdown.php' );
    require( get_template_directory() . '/inc/elements/cms_button.php' );
    require( get_template_directory() . '/inc/elements/cms_pricing.php' );
    require( get_template_directory() . '/inc/elements/cms_video.php' );
    require( get_template_directory() . '/inc/elements/cms_heading_typing.php' );
    add_filter('cms-shorcode-list', 'bo_shortcodes');
     
}

/**
 * Custom params & remove VC Elements.
 * 
 * @author FOX
 */
add_action('vc_after_init', 'bo_vc_after');

function bo_vc_after() {
    require( get_template_directory() . '/vc_params/vc_column_text.php' ); 
    require( get_template_directory() . '/vc_params/vc_row.php' ); 
    require( get_template_directory() . '/vc_params/vc_column.php' );
    require( get_template_directory() . '/vc_params/vc_progress_bar.php' );
    require( get_template_directory() . '/vc_params/vc_custom_heading.php' ); 
    
    vc_add_shortcode_param( 'cms_time', 'bo_time_settings_field', get_template_directory_uri() . '/assets/js/jquery.datetimepicker.js' );
}

function bo_time_settings_field($settings, $value) {
    return '<div class="date-field cms_datetime_block" data-type="datetime" data-format="m/d/Y H:i">'
        	.'<input type="text" name="'.esc_attr( $settings['param_name']).'" class="wpb_vc_param_value wpb-textinput" value="'.esc_attr( $value ).'"/>'
        .'</div>';
}

/* Add widgets */
require( get_template_directory() . '/inc/widgets/recent_post_v2.php' );

/* Custom News Twitter template */
add_filter('znews_twitter/widget/template', 'bo_news_twitter');
function bo_news_twitter(){
	return get_template_directory() . '/inc/widgets/feed.php';
}
/**
 * add google font
 */
function bo_open_sans() {
    $fonts_url = '';
    $opensans = _x('on','Open Sans font: on or off','wpbo');
     if ( 'off' !== $opensans ) {
        $query_args = array(
        'family' =>  'Open+Sans:300,300i,400,400i,600,600i,700,700i,800,800i', 
        'subset' => urlencode( 'latin,latin-ext' )
        );
      }
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    return esc_url_raw( $fonts_url );
} 
function bo_work_sans() {
    $fonts_url = '';
    $work_sans = _x( 'on', 'Work Sans font: on or off', 'wpbo' );
    if ( 'off' !== $work_sans ) {
        $query_args = array(
        'family' =>  'Work+Sans:100,200,300,400,500,600,700,800,900', 
        'subset' => urlencode( 'latin,latin-ext' )
        );
    }  
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    return esc_url_raw( $fonts_url );
     
}
function bo_montserrat() {
    $fonts_url = '';
    $montserrat = _x( 'on', 'Montserrat: on or off', 'wpbo' );
    if ( 'off' !== $montserrat ) {
        $query_args = array(
        'family' =>  'Montserrat:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i', 
        'subset' => urlencode( 'latin,latin-ext' )
        );
    }  
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    return esc_url_raw( $fonts_url );
     
}
function bo_raleway() {
    $fonts_url = '';
    $raleway = _x('on','Raleway font: on or off','wpbo');
     if ( 'off' !== $raleway ) {
        $query_args = array(
        'family' =>  'Raleway:400,100,100italic,200,200italic,300,300italic,400italic,500,500italic,600,600italic,700,700italic,800,800italic', 
        'subset' => urlencode( 'latin,latin-ext' )
        );
      }
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    return esc_url_raw( $fonts_url );
} 
function bo_roboto() {
    $fonts_url = '';
    $roboto = _x( 'on', 'Roboto font: on or off', 'wpbo' );
    if ( 'off' !== $roboto ) {
        $query_args = array(
        'family' =>  'Roboto:100,100i,300,300i,400,400i,500,500i,700,700i,900,900i', 
        'subset' => urlencode( 'latin,latin-ext' )
        );
    }  
    $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    return esc_url_raw( $fonts_url );
}

/**
 * Enqueue scripts and styles for front-end.
 * @author Fox
 * @since CMS SuperHeroes 1.0
 */
function bo_front_end_scripts() {
    
	global $wp_styles, $opt_meta_options;
 
    /* Add Google font */
    
    wp_enqueue_style( 'wpbo-open-sans-font', bo_open_sans(), array(), null );
    wp_enqueue_style( 'wpbo-work-sans-font', bo_work_sans(), array(), null );
    wp_enqueue_style( 'wpbo-montserrat-font', bo_montserrat(), array(), null );
    wp_enqueue_style( 'wpbo-raleway-font', bo_raleway(), array(), null );
    wp_enqueue_style( 'wpbo-roboto-font', bo_roboto(), array(), null );
    
	/* Adds JavaScript Bootstrap. */
	wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '3.3.2');
	
    /* Adds JavaScript Bootstrap. */
	wp_enqueue_script('wow-effect', get_template_directory_uri() . '/assets/js/wow.min.js', array( 'jquery' ), '1.0.1', true);
    
    /* Adds magnific popup. */
    wp_enqueue_script('magnific-popup', get_template_directory_uri() . '/assets/js/jquery.magnific-popup.min.js', array( 'jquery' ), '1.0.0', true);
    
    /* Add mousewheel js*/
    wp_enqueue_script('mousewheel', get_template_directory_uri() . '/assets/js/jquery.mousewheel.min.js', array( 'jquery' ), '1.0.0', true);
    
    /* Register isotope */
    wp_enqueue_script('isotope',get_template_directory_uri().'/assets/js/isotope.js',array('jquery'),'1.5.25',true);
     	
	/* Add main.js */
	wp_enqueue_script('wpbo-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery'), '1.0.0', true);
	
	/* Add menu.js */
	wp_enqueue_script('wpbo-menu', get_template_directory_uri() . '/assets/js/menu.js', array('jquery'), '1.0.0', true);
    
	/* Comment */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/** ----------------------------------------------------------------------------------- */
	
	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css');
	
    /* Load magnific popup css*/
    wp_enqueue_style('magnific-popup-css', get_template_directory_uri() . '/assets/css/magnific-popup.css', array(), '1.0.1');
    
	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css');
    
    /* Loads Stroke gap font */
	wp_enqueue_style('font-stroke-7-icon', get_template_directory_uri() . '/assets/css/pe-icon-7-stroke.css');	
    
    /* Loads Stroke gap font */
	wp_enqueue_style('font-linearicons-icon', get_template_directory_uri() . '/assets/css/linearicons.css');	
		
	/* Loads our main stylesheet. */
	wp_enqueue_style( 'wpbo-style', get_stylesheet_uri());

	/* Loads the Internet Explorer specific stylesheet. */
	wp_enqueue_style( 'wpbo-ie', get_template_directory_uri() . '/assets/css/ie.css');
	
	/* ie */
	$wp_styles->add_data( 'wpbo-ie', 'conditional', 'lt IE 9' );
	
	/* Load static css*/
	wp_enqueue_style('wpbo-static', get_template_directory_uri() . '/assets/css/static.css');
}

add_action( 'wp_enqueue_scripts', 'bo_front_end_scripts' );

/**
 * load admin scripts.
 * 
 * @author FOX
 */
function bo_admin_scripts(){

	/* Loads Bootstrap stylesheet. */
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), '4.3.0');
    wp_enqueue_style('wpbo-admin-css', get_template_directory_uri() . '/assets/css/admin-style.css', array(), '1.0.0');
    
	$screen = get_current_screen();

	/* load js for edit post. */
	if($screen->post_type == 'post'){
		/* post format select. */
		wp_enqueue_script('post-format', get_template_directory_uri() . '/assets/js/post-format.js', array(), '1.0.0', true);
	}
    wp_register_style('jquery-datetimepicker', get_template_directory_uri().'/assets/css/jquery.datetimepicker.css');
    wp_enqueue_style('jquery-datetimepicker');
    wp_enqueue_script('be-time', get_template_directory_uri() . '/assets/js/datetime-element.js');
}

add_action( 'admin_enqueue_scripts', 'bo_admin_scripts' );

/**
 * Register sidebars.
 *
 * Registers our main widget area and the front page widget areas.
 *
 * @since Fox
 */
function bo_widgets_init() {

	global $opt_theme_options;

	register_sidebar( array(
		'name' => esc_html__( 'Main Sidebar', 'wpbo' ),
		'id' => 'sidebar-1',
		'description' => esc_html__( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpbo' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Newsletter sidebar 1', 'wpbo' ),
		'id' => 'newsletter',
		'description' => esc_html__( 'Appears on page builder', 'wpbo' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );
	register_sidebar( array(
		'name' => esc_html__( 'Newsletter sidebar 2', 'wpbo' ),
		'id' => 'newsletter2',
		'description' => esc_html__( 'Appears on page builder', 'wpbo' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s newsletter-abs">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="wg-title">',
		'after_title' => '</h3>',
	) );
    
    /* Shop Sidebar */
    if (class_exists('WooCommerce')) {
        register_sidebar(array(
            'name'          => esc_html__('WooCommerce Sidebar', 'wpbo'),
            'id'            => 'sidebar-shop',
            'description'   => esc_html__('Appears in WooCommerce Archive page', 'wpbo'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h4 class="wg-title"><span>',
            'after_title'   => '</span></h4>',
        ));
    }
     
	/* footer-top */
	if(!empty($opt_theme_options['footer-top-column'])) {

		for($i = 1 ; $i <= $opt_theme_options['footer-top-column'] ; $i++){
			register_sidebar(array(
				'name' => sprintf(esc_html__('Footer Top %s', 'wpbo'), $i),
				'id' => 'sidebar-footer-top-' . $i,
				'description' => esc_html__('Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpbo'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget' => '</aside>',
				'before_title' => '<h3 class="wg-title">',
				'after_title' => '</h3>',
			));
		}
	}

	/* footer-top */
	if(!empty($opt_theme_options['footer-bottom-column'])) {

		for($i = 1 ; $i <= $opt_theme_options['footer-bottom-column'] ; $i++){
			register_sidebar(array(
				'name' => sprintf(esc_html__('Footer Bottom %s', 'wpbo'), $i),
				'id' => 'sidebar-footer-bottom-' . $i,
				'description' => esc_html__('Appears on posts and pages except the optional Front Page template, which has its own widgets', 'wpbo'),
				'before_widget' => '<aside id="%1$s" class="widget %2$s">',
				'after_widget' => '</aside>',
				'before_title' => '<h3 class="wg-title">',
				'after_title' => '</h3>',
			));
		}
	}
}

add_action( 'widgets_init', 'bo_widgets_init' );

/**
 * Display navigation to next/previous comments when applicable.
 *
 * @since 1.0.0
 */
function bo_comment_nav() {
    // Are there comments to navigate through?
    if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
    ?>
	<nav class="navigation comment-navigation"  >
		<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'wpbo' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( esc_html__( 'Older Comments', 'wpbo' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( esc_html__( 'Newer Comments', 'wpbo' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}

/**
 * Display navigation to next/previous set of posts when applicable.
 *
 * @since 1.0.0
 */
function bo_paging_nav() {
    // Don't print empty markup if there's only one page.
	if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
		return;
	}

	$paged        = get_query_var( 'paged' ) ? intval( get_query_var( 'paged' ) ) : 1;
	$pagenum_link = html_entity_decode( get_pagenum_link() );
	$query_args   = array();
	$url_parts    = explode( '?', $pagenum_link );

	if ( isset( $url_parts[1] ) ) {
		wp_parse_str( $url_parts[1], $query_args );
	}

	$pagenum_link = remove_query_arg( array_keys( $query_args ), $pagenum_link );
	$pagenum_link = trailingslashit( $pagenum_link ) . '%_%';

	// Set up paginated links.
	$links = paginate_links( array(
			'base'     => $pagenum_link,
			'total'    => $GLOBALS['wp_query']->max_num_pages,
			'current'  => $paged,
			'mid_size' => 1,
			'add_args' => array_map( 'urlencode', $query_args ),
			'prev_text' => '<i class="fa fa-angle-left"></i> Prev',
			'next_text' => 'Next <i class="fa fa-angle-right"></i>',
	) );

	if ( $links ) :

	?>
	<nav class="navigation paging-navigation clearfix text-center">
			<div class="pagination loop-pagination">
				<?php echo wp_kses_post($links); ?>
			</div><!-- .pagination -->
	</nav><!-- .navigation -->
	<?php
	endif;
}

/**
* Display navigation to next/previous post when applicable.
*
* @since 1.0.0
*/
function bo_post_nav() {
    global $post,$opt_theme_options;
     
    if(!isset($opt_theme_options['single_post_nav']) ||  ( isset($opt_theme_options['single_post_nav']) && !$opt_theme_options['single_post_nav']))
        return;

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
	<nav class="navigation post-navigation"  >
		<div class="nav-links clearfix">
			<?php
			$prev_post = get_previous_post();
			if (!empty( $prev_post )): ?>
			  <a class="post-prev left" href="<?php echo get_permalink( $prev_post->ID ); ?>"><i class="fa fa-long-arrow-left"></i><?php echo esc_html__('Previous','wpbo'); ?></a>
			<?php endif; ?>
			<?php
			$next_post = get_next_post();
			if ( is_a( $next_post , 'WP_Post' ) ) { ?>
			  <a class="post-next right" href="<?php echo get_permalink( $next_post->ID ); ?>"><?php echo esc_html__('Next','wpbo'); ?><i class="fa fa-long-arrow-right"></i></a>
			<?php } ?>

			</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
function bo_port_nav_wrap(){
    global $opt_theme_options;
    if(isset($opt_theme_options['single_port_nav'])){
        if( $opt_theme_options['single_port_nav'] || $opt_theme_options['single_port_show_all']){
            echo '<div class="port-entry-foot">';
                bo_port_nav();
            echo '</div>';
        }
    }
}
function bo_port_nav() {
    global $post,$opt_theme_options;
     
    if(!isset($opt_theme_options['single_port_nav']) ||  ( isset($opt_theme_options['single_port_nav']) && !$opt_theme_options['single_port_nav']))
        return;

    // Don't print empty markup if there's nowhere to navigate.
    $previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
    $next     = get_adjacent_post( false, '', false );

    if ( ! $next && ! $previous )
        return;
    ?>
	<nav class="navigation post-navigation"  >
		<div class="nav-links clearfix">
			<?php
			$prev_post = get_previous_post();
			if (!empty( $prev_post )): ?>
			  <a class="post-prev left" href="<?php echo get_permalink( $prev_post->ID ); ?>"><i class="fa fa-long-arrow-left"></i><?php echo esc_html__('Previous','wpbo'); ?></a>
			<?php endif; ?>
			<?php
			$next_post = get_next_post();
			if ( is_a( $next_post , 'WP_Post' ) ) { ?>
			  <a class="post-next right" href="<?php echo get_permalink( $next_post->ID ); ?>"><?php echo esc_html__('Next','wpbo'); ?><i class="fa fa-long-arrow-right"></i></a>
			<?php } ?>

			</div><!-- .nav-links -->
	</nav><!-- .navigation -->
    <?php
    if(isset($opt_theme_options['single_port_show_all']) && $opt_theme_options['single_port_show_all']){
        $all_text = !empty($opt_theme_options['single_port_show_all_text']) ? $opt_theme_options['single_port_show_all_text'] : esc_html__('All Project','wpbo');
        $all_url =  !empty($opt_theme_options['single_port_show_all_url']) ? esc_url($opt_theme_options['single_port_show_all_url']) : '#';
        echo '<a class="show-all" href="'.$all_url.'" title="'.$all_text.'">'.esc_html($all_text).'</a>';
    }
    ?>
	<?php
}

/* Add Custom Comment */
function bo_comment($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
    ?>
    <<?php echo esc_attr($tag) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
    <?php if ( 'div' != $args['style'] ) : ?>
    <div id="div-comment-<?php comment_ID() ?>" class="comment-body clearfix">
    <?php endif; ?>
    <div class="comment-author-image vcard">
    	<?php echo get_avatar( $comment, 70 ); ?>
    </div>
    
    <div class="comment-main">
    
        <div class="comment-meta commentmetadata">
            <?php
    		echo '<h5 class="comment-author">'. get_comment_author_link() .'<span class="comment-date">';
                 $comment_date = get_comment_date('F j, Y',get_comment_ID()); 
        	    	  echo esc_attr($comment_date);  
        	echo '</span></h5>';
            ?>
            <div class="comment-reply">
                <i class="fa fa-mail-reply"></i>
    		  <?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
    		</div>	
    	</div>
        
    	<div class="comment-content">
            <?php comment_text(); ?>
    	</div>
        <?php if ( $comment->comment_approved == '0' ) : ?>
        	<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.' , 'wpbo'); ?></em>
        <?php endif; ?>
    </div>

    <?php if ( 'div' != $args['style'] ) : ?>
    </div>
    <?php endif; ?>
    <?php
}

/**
 * Move comment form field to bottom
 */
function red_organicfood_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'red_organicfood_comment_field_to_bottom' ); 

/**
 * limit words
 */

function bo_limit_words($string) {
    global $opt_theme_options;
    if(isset($opt_theme_options['excerpt_length']) && !empty($opt_theme_options['excerpt_length']) && (int) $opt_theme_options['excerpt_length'] > 0){
        $word_limit =  $opt_theme_options['excerpt_length'];
        $words = explode(' ', $string, ($word_limit + 1));
        if (count($words) > $word_limit) {
            array_pop($words);
        }
        return implode(' ', $words)."...";
    }else{
        return $string;
    }
}

function bo_grid_limit_words($string, $word_limit) {
    $words = explode(' ', $string, ($word_limit + 1));
    if (count($words) > $word_limit) {
        array_pop($words);
    }
    return implode(' ', $words)." ...";
}

/* Remove [...] after excerpt text */
function bo_new_excerpt_more( $more ) {
    return '...';
}
add_filter('excerpt_more', 'bo_new_excerpt_more');

/* Custom excerpt length */
function bo_custom_excerpt_length( $length ) { 
	return 50;
}

add_filter( 'excerpt_length', 'bo_custom_excerpt_length', 999 );

/* core functions. */
require_once( get_template_directory() . '/inc/functions.php' );

/**
 * theme actions.
 */

/* add footer back to top. */
add_action('wp_footer', 'bo_footer_back_to_top');
 
 