<?php

/**
 * Auto create .css file from Theme Options
 * @author Fox
 * @version 1.0.0
 */
class CMSSuperHeroes_StaticCss
{

    public $scss;
    
    function __construct()
    {
        if(!class_exists('scssc'))
            return;

        /* scss */
        $this->scss = new scssc();
        
        /* set paths scss */
        $this->scss->setImportPaths(get_template_directory() . '/assets/scss/');
             
        /* generate css over time */
		add_action('wp', array($this, 'generate_over_time'));
        
        /* save option generate css */
       	add_action("redux/options/opt_theme_options/saved", array($this,'generate_file'));
    }
	
    public function generate_over_time(){
    	
    	global $opt_theme_options;

    	if (!empty($opt_theme_options) && $opt_theme_options['dev_mode']){
    	    $this->generate_file();
    	}
    }
    /**
     * generate css file.
     *
     * @since 1.0.0
     */
    public function generate_file()
    {
        global $opt_theme_options, $wp_filesystem;
        
        if (empty($wp_filesystem) || !isset($opt_theme_options))
            return;
            
        $options_scss = get_template_directory() . '/assets/scss/options.scss';

        /* delete files options.scss */
        $wp_filesystem->delete($options_scss);

        /* write options to scss file */
        $wp_filesystem->put_contents($options_scss, $this->css_render(), FS_CHMOD_FILE); // Save it

        /* minimize CSS styles */
        if (!$opt_theme_options['dev_mode'])
            $this->scss->setFormatter('scss_formatter_compressed');

        /* compile scss to css */
        $css = $this->scss_render();

        $file = "static.css";

        $file = get_template_directory() . '/assets/css/' . $file;

        /* delete files static.css */
        $wp_filesystem->delete($file);

        /* write static.css file */
        $wp_filesystem->put_contents($file, $css, FS_CHMOD_FILE); // Save it
    }
    
    /**
     * scss compile
     * 
     * @since 1.0.0
     * @return string
     */
    public function scss_render(){
        /* compile scss to css */
        return $this->scss->compile('@import "master.scss"');
    }
    
    public function primary_HexToRGB($hex,$opacity = 1) {
        $hex = str_replace("#",null, $hex);
        $color = array();
        if(strlen($hex) == 3) {
            $color['r'] = hexdec(substr($hex,0,1).substr($hex,0,1));
            $color['g'] = hexdec(substr($hex,1,1).substr($hex,1,1));
            $color['b'] = hexdec(substr($hex,2,1).substr($hex,2,1));
            $color['a'] = $opacity;
        }
        else if(strlen($hex) == 6) {
            $color['r'] = hexdec(substr($hex, 0, 2));
            $color['g'] = hexdec(substr($hex, 2, 2));
            $color['b'] = hexdec(substr($hex, 4, 2));
            $color['a'] = $opacity;
        }
        $color = "rgba(".implode(', ', $color).")";
        return $color;
    }
    /**
     * main css
     *
     * @since 1.0.0
     * @return string
     */
    public function css_render()
    {
        global $opt_theme_options;
        
        ob_start();
        
        /* primary_color */
        
        if(!empty($opt_theme_options['font_body']['color']))
            echo '$body_color:'.esc_attr($opt_theme_options['font_body']['color']).';';
            
        if(!empty($opt_theme_options['primary_color'])){
            echo '$primary_color:'.esc_attr($opt_theme_options['primary_color']).';';
            echo '$primary_color_hex:'.$this->primary_HexToRGB($opt_theme_options['primary_color'],0.8).';';
        }
        if(!empty($opt_theme_options['second_color']))
            echo '$second_color:'.esc_attr($opt_theme_options['second_color']).';';
        
        if(!empty($opt_theme_options['link_color']['regular']))
            echo '$link_color_regular:'.esc_attr($opt_theme_options['link_color']['regular']).';';
            
        if(!empty($opt_theme_options['link_color']['hover']))
            echo '$link_color_hover:'.esc_attr($opt_theme_options['link_color']['hover']).';';
        
        if(!empty($opt_theme_options['link_color_second']['regular']))
            echo '$link_color_second_regular:'.esc_attr($opt_theme_options['link_color_second']['regular']).';';
            
        if(!empty($opt_theme_options['link_color_second']['hover']))
            echo '$link_color_second_hover:'.esc_attr($opt_theme_options['link_color_second']['hover']).';';
            
           
        if( !empty($opt_theme_options['header_padding']['padding-bottom']) ){
            echo '$menu_space_bottom:'.($opt_theme_options['header_padding']['padding-bottom'] + 2).'px;';
            echo '$submenu_pos_ontop:'.($opt_theme_options['header_padding']['padding-bottom'] + 57).'px;';
        }else{
            echo '$menu_space_bottom:17px;';
            echo '$submenu_pos_ontop:72px;';
        } 
        
        if( !empty($opt_theme_options['sticky_header_padding']['padding-bottom']) ){
            echo '$menu_sticky_space_bottom:'.($opt_theme_options['sticky_header_padding']['padding-bottom'] + 2).'px;';
            echo '$submenu_sticky_pos_ontop:'.($opt_theme_options['sticky_header_padding']['padding-bottom'] + 57).'px;';
        }else{
            echo '$menu_sticky_space_bottom:2px;';
            echo '$submenu_sticky_pos_ontop:57px;';
        } 
        
        if( !empty($opt_theme_options['btn_color']))
            echo '$btn_color:'.$opt_theme_options['btn_color'].';';
        else 
            echo '$btn_color:#fff;';
            
        if( !empty($opt_theme_options['btn_background']['color']))
            echo '$btn_background:'.$opt_theme_options['btn_background']['color'].';';
        else 
            echo '$btn_background:#2ecc71;';
        
        if( !empty($opt_theme_options['btn_border_color']))
            echo '$btn_border_color:'.$opt_theme_options['btn_border_color'].';';
        else 
            echo '$btn_border_color:#2ecc71;';
        
        if( !empty($opt_theme_options['btn_hover_color']))
            echo '$btn_hover_color:'.$opt_theme_options['btn_hover_color'].';';
        else 
            echo '$btn_hover_color:#363636;';
            
        if( !empty($opt_theme_options['btn_hover_background']['color']))
            echo '$btn_hover_background:'.$opt_theme_options['btn_hover_background']['color'].';';
        else 
            echo '$btn_hover_background:transparent;';
        
        if( !empty($opt_theme_options['btn_hover_border_color']))
            echo '$btn_hover_border_color:'.$opt_theme_options['btn_hover_border_color'].';';
        else 
            echo '$btn_hover_border_color:#2ecc71;';
           
        if(!empty($opt_theme_options['logo_max_height']['height']))
            echo '#cshero-header-logo img{max-height:'.esc_attr($opt_theme_options['logo_max_height']['height']).';}';
  
        return ob_get_clean();
    }
}

new CMSSuperHeroes_StaticCss();