<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */
if (! class_exists('Redux')) {
    return;
}

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters('opt_name', 'opt_theme_options');

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version' => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type' => 'menu',
    // Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true,
    // Show the sections below the admin menu item or not
    'menu_title' => $theme->get('Name'),
    'page_title' => $theme->get('Name'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key' => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography' => true,
    // Use a asynchronous font on the front end or font string
    // 'disable_google_fonts_link' => true, // Disable this in case you want to create your own google fonts loader
    'admin_bar' => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-smiley',
    // Choose an icon for the admin bar menu
    'admin_bar_priority' => 50,
    // Choose an priority for the admin bar menu
    'global_variable' => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Show the time the page took to load, etc
    'update_notice' => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    // Enable basic customizer support
    // 'open_expanded' => true, // Allow you to start the panel in an expanded way initially.
    'disable_save_warn' => true, // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority' => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon' => 'dashicons-dashboard',
    // Specify a custom URL to an icon
    'last_tab' => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon' => 'dashicons-smiley',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug' => '',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show' => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark' => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time' => 60 * MINUTE_IN_SECONDS,
    'output' => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit' => '', // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints' => array(
        'icon' => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color' => 'lightgray',
        'icon_size' => 'normal',
        'tip_style' => array(
            'color' => 'red',
            'shadow' => true,
            'rounded' => false,
            'style' => ''
        ),
        'tip_position' => array(
            'my' => 'top left',
            'at' => 'bottom right'
        ),
        'tip_effect' => array(
            'show' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'mouseover'
            ),
            'hide' => array(
                'effect' => 'slide',
                'duration' => '500',
                'event' => 'click mouseleave'
            )
        )
    )
);

Redux::setArgs($opt_name, $args);

/**
 * General Options.
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('General', 'wpbo'),
    'icon' => 'el-icon-adjust-alt',
    'fields' => array(
        array(
            'title'             => esc_html__('Body Background', 'wpbo'),
            'subtitle'          => esc_html__('Body background.', 'wpbo'),
            'id'                => 'general_background',
            'type'              => 'background',
            'output'            => array( 'body' ),
            
        ),
        array(
            'subtitle'          => esc_html__('Enable back to top button.', 'wpbo'),
            'id'                => 'general_back_to_top',
            'type'              => 'switch',
            'title'             => esc_html__('Back To Top', 'wpbo'),
            'default'           => true,
        )
    )
));

/**
 * Header Options
 * 
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Header', 'wpbo'),
    'icon' => 'el-icon-credit-card',
    'fields' => array(
        array(
            'id'                => 'header_layout',
            'title'             => esc_html__('Layouts', 'wpbo'),
            'subtitle'          => esc_html__('select a layout for header', 'wpbo'),
            'default'           => 'default',
            'type'              => 'image_select',
            'options'           => array(
                                        'default' => get_template_directory_uri().'/assets/images/header/h-default.png',
                                    )
        ),
        array(
            'subtitle'          => esc_html__('Header full width', 'wpbo'),
            'id'                => 'header_full_width',
            'type'              => 'switch',
            'title'             => esc_html__('Full Width', 'wpbo'),
            'default'           => false,
        ), 
        array(
            'id'                => 'header_background_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Header background color', 'wpbo' ),
            'output'   => array(
                'background-color' => '#cshero-header'
            ),
        ),
        array(
            'title'             => esc_html__('Background Image', 'wpbo'),
            'subtitle'          => esc_html__('Header background image.', 'wpbo'),
            'id'                => 'header_background_image',
            'type'              => 'background',
            'preview'           => true,
            'background-color'  => false,
            'output'            => array( '#cshero-header' )
        ),
         
        array(
            'title'             => esc_html__('Header padding', 'wpbo'),
            'subtitle'          => esc_html__('Padding top and bottom', 'wpbo'),
            'id'                => 'header_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array( 'em', 'px', '%' ),
            'top'               => true,
            'right'             => false,
            'bottom'            => true,
            'left'              => false,
            'output'            => array( '.site-header .header-nav' ),
        ),
    )
));
/* Header logo */
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-minus',
    'title' => esc_html__('Logo', 'wpbo'),
    'subsection' => true,
    'fields' => array(
        array(
            'title'             => esc_html__('Logo Type', 'wpbo'),
            'subtitle'          => esc_html__('Image / Text.', 'wpbo'),
            'id'                => 'logo_type',
            'type'              => 'button_set',
            'options'           => array(
                1 => esc_html__('Image', 'wpbo'),
                0 => esc_html__('Text', 'wpbo')
            ),
            'default'           => 1
        ),
        array(
            'title'             => esc_html__('Select Logo', 'wpbo'),
            'subtitle'          => esc_html__('Select an image file for your logo.', 'wpbo'),
            'id'                => 'main_logo',
            'type'              => 'media',
            'url'               => true,
            'default'           => array(
                'url'=>get_template_directory_uri().'/assets/images/logo.png'
            ),
            'required'          => array( 'logo_type', '=', 1 )
        ),
        array(
            'subtitle'          => esc_html__('Set max height for logo.', 'wpbo'),
            'id'                => 'logo_max_height',
            'type'              => 'dimensions',
            'units'             => array('px'),
            'width'             => false,
            'title'             => esc_html__('Logo Max Height', 'wpbo'),
            'required'          => array( 'logo_type', '=', 1 )
        ),
        array(
            'subtitle'          => esc_html__('Add custom logo text.', 'wpbo'),
            'id'                => 'logo_text',
            'type'              => 'text',
            'title'             => esc_html__('Logo Text', 'wpbo'),
            'required'          => array( 'logo_type', '=', 0 )
        ),
        array(
            'subtitle'          => esc_html__('Add custom slogan Text.', 'wpbo'),
            'id'                => 'logo_text_sologan',
            'type'              => 'text',
            'title'             => esc_html__('Slogan Text', 'wpbo'),
            'required'          => array( 'logo_type', '=', 0 )
        ), 
        array(
            'id'                => 'logo_text_color',
            'type'              => 'color',
            'title'             => esc_html__( 'Text Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select text color for logo', 'wpbo' ),
            'output'            => array( '.main_logo' ),
            'required'          => array( 'logo_type', '=', 0 )
        ),
        array(
            'id'                => 'logo_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Links Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select links color for logo', 'wpbo' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( '.main_logo a' ),
            'required'          => array( 'logo_type', '=', 0 )
        ),
        array(
            'title'     => esc_html__('Number Columns', 'wpbo'),
            'subtitle'  => esc_html__('Number of columns to display logo width', 'wpbo'),
            'id'        => 'logo_number_column',
            'type'      => 'slider',
            "default"   => 3,
            "min"       => 1,
            "step"      => 1,
            "max"       => 5,
            'display_value' => 'label',
        ),
        array(
            'title'             => esc_html__('Typography', 'wpbo'),
            'subtitle'          => esc_html__('typography.', 'wpbo'),
            'id'                => 'header_logo_text_typography',
            'type'              => 'typography',
            'google'            => true,
            'text-align'        => false,
            'color'             => false,
            'output'            => array( 
                '.main_logo .site-title,.main_logo .site-title a' 
            ),
            'required'          => array( 'logo_type', '=', 0 )
        ), 
        array(
            'title' => esc_html__('Header transparent logo', 'wpbo'),
            'id'   => 'hdtp-logo',
            'type' => 'info',
            'style' => 'success',
        ),
        array(
            'title'             => esc_html__('Header transparent logo', 'wpbo'),
            'subtitle'          => esc_html__('Select an image file for header transparent logo.', 'wpbo'),
            'id'                => 'tran_logo',
            'type'              => 'media',
            'url'               => true,
            'default'           => array(
                'url'=>get_template_directory_uri().'/assets/images/tran-logo.png'
            ),
            'required'          => array( 'logo_type', '=', 1 )
        ),
        array(
            'id'                => 'tran_logo_text_color',
            'type'              => 'color',
            'title'             => esc_html__( 'Text Color In Header Transparent', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select text color for logo in header transparent', 'wpbo' ),
            'output'            => array( '.header-transparent:not(.header-fixed) .main_logo' ),
            'required'          => array( 'logo_type', '=', 0 )
        ),
        array(
            'id'                => 'tran_logo_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Links Color In Header Transparent', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select links color for logo in header transparent', 'wpbo' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( '.header-transparent:not(.header-fixed) .main_logo a' ),
            'required'          => array( 'logo_type', '=', 0 )
        ),
    )
));
/* Main menu */
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-minus',
    'title' => esc_html__('Main menu', 'wpbo'),
    'subsection' => true,
    'fields' => array(
        array(
            'title' => esc_html__('MAIN MENU LEVEL 1', 'wpbo'),
            'id'   => 'mmnlv1-panel',
            'type' => 'info',
            'style' => 'success',
        ),
        array(
            'id'                => 'main_menu_level1_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Link color', 'wpbo' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( 
                '#cshero-header-navigation .main-navigation .menu-main-menu > li > a'
            ),
        ),
        
        array(
            'id'                => 'main_menu_level1_current_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Hover and Current color', 'wpbo' ),
            'regular'           => true,
            'hover'             => false,
            'active'            => false,
            'visited'           => false,
            'output'            => array(  
                '#cshero-header-navigation .main-navigation .menu-main-menu > li.current-menu-ancestor > a,  
                #cshero-header-navigation .main-navigation .menu-main-menu > li.current-menu-item > a,
                #cshero-header-navigation .main-navigation .menu-main-menu > li > a:hover',
            ),
        ),
        array(
            'title'             => esc_html__('Menu item space', 'wpbo'),
            'subtitle'          => esc_html__('Number of px between menu item', 'wpbo'),
            'id'                => 'menu_item_space',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array( 'em', 'px', '%' ),
            'top'               => false,
            'right'             => true,
            'bottom'            => false,
            'left'              => false,
            'output'            => array( '#cshero-header-navigation .main-navigation .menu-main-menu > li > a' )
        ),
        array(
            'subtitle'          => esc_html__('Show arrow down icon right', 'wpbo'),
            'id'                => 'show_arrow_down_icon_right',
            'type'              => 'switch',
            'title'             => esc_html__('Show arrow down icon right', 'wpbo'),
            'default'           => false,
        ),
        array(
            'title'             => esc_html__('Typography', 'wpbo'),
            'id'                => 'main_menu_level1_typography',
            'type'              => 'typography',
            'google'            => true,
            'text-align'        => false,
            'color'             => false,
            'line-height'       => true,
            'font-size'         => true,
            'output'            => array( 
                '#cshero-header-navigation .main-navigation ul.nav-menu > li > a' 
            ),
        ),
        array(
            'title' => esc_html__('SUB MENU', 'wpbo'),
            'id'   => 'msmilm-panel',
            'type' => 'info',
            'style' => 'success',
        ),
        array(
            'id'                => 'menu_dropdown_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Menu dropdown link color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select links color in menu dropdown', 'wpbo' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( 
            '#cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li,#cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li a'
            ),
        ),
        array(
            'id'                => 'menu_dropdown_background_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background', 'wpbo' ),
            'output'   => array(
                'background-color' => '#cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu, #cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu ul',
            ),
            
        ),
        array(
            'id'                => 'menu_dropdown_hover_background_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Menu hover background', 'wpbo' ),
            'output'   => array(
                'background-color' => '#cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li:hover'
            ),
        ),
        array(
            'id'                => 'menu_dropdown_current_background_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Current menu background', 'wpbo' ),
            'output'   => array(
                'background-color' => '#cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li.current-menu-item'
            ),
        ),
        array(
            'id'                => 'menu_dropdown_current_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Current menu color', 'wpbo' ),
            'regular'           => true,
            'hover'             => false,
            'active'            => false,
            'visited'           => false,
            'output'            => array( 
            '#cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li.current-menu-item > a' ),
        ),
        array(
            'id'                => 'menu_dropdown_border_bottom_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Menu border bottom color', 'wpbo' ), 
            'output'   => array(
                'border-bottom-color' => '.cshero-main-header #cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li',
            ), 
        ),
        array(
            'title'             => esc_html__('Typography', 'wpbo'),
            'subtitle'          => esc_html__('typography.', 'wpbo'),
            'id'                => 'menu_dropdown_typography',
            'type'              => 'typography',
            'google'            => true,
            'text-align'        => false,
            'color'             => false,
            'output'            => array( 
                '#cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li a, 
                .header-style-1 #cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li a,
                .header-style-2 #cshero-header-navigation .main-navigation .menu-main-menu > li ul.sub-menu li a ' 
            ),
        ),
    )
));
/* Menu Sticky */
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-minus',
    'title' => esc_html__('Menu Sticky', 'wpbo'),
    'subsection' => true,
    'fields' => array(
        array(
            'subtitle'          => esc_html__('enable sticky mode for menu.', 'wpbo'),
            'id'                => 'menu_sticky',
            'type'              => 'switch',
            'title'             => esc_html__('Sticky Header', 'wpbo'),
            'default'           => false,
        ),
        array(
            'title'             => esc_html__('Logo Type', 'wpbo'),
            'subtitle'          => esc_html__('From Main / Image / Text.', 'wpbo'),
            'id'                => 'sticky_logo_type',
            'type'              => 'button_set',
            'options'           => array(
                'default' => esc_html__('Main', 'wpbo'),
                'img' => esc_html__('Image', 'wpbo'),
                'text' => esc_html__('Text', 'wpbo')
            ),
            'default'           => 'default',
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Select Logo', 'wpbo'),
            'subtitle'          => esc_html__('Select an image file for your logo.', 'wpbo'),
            'id'                => 'sticky_logo',
            'type'              => 'media',
            'url'               => true,
            'default'           => array(
                'url'=>get_template_directory_uri().'/assets/images/logo.png'
            ),
            'required'          => array( 'sticky_logo_type', '=', 'img' )
        ),
        array(
            'subtitle'          => esc_html__('Add custom logo text.', 'wpbo'),
            'id'                => 'sticky_logo_text',
            'type'              => 'text',
            'title'             => esc_html__('Logo Text', 'wpbo'),
            'required'          => array( 'sticky_logo_type', '=', 'text' )
        ),
        array(
            'subtitle'          => esc_html__('Add custom sologan Text.', 'wpbo'),
            'id'                => 'sticky_logo_text_sologan',
            'type'              => 'text',
            'title'             => esc_html__('Sologan Text', 'wpbo'),
            'required'          => array( 'sticky_logo_type', '=', 'text' )
        ),
        array(
            'id'                => 'sticky_logo_text_color',
            'type'              => 'color',
            'title'             => esc_html__( 'Text Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select text color for logo', 'wpbo' ),
            'output'            => array( '.sticky_logo' ),
            'required'          => array( 'sticky_logo_type', '=', 'text' )
        ),
        array(
            'id'                => 'sticky_logo_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Links Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select links color for logo', 'wpbo' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( '.sticky_logo a' ),
            'required'          => array( 'sticky_logo_type', '=', 'text' )
        ),
        array(
            'id'                => 'sticky_background_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Header background color', 'wpbo' ),
            'output'   => array(
                'background-color' => '.site-header .header-fixed .header-nav'
            ),
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Background Image', 'wpbo'),
            'subtitle'          => esc_html__('Header background image.', 'wpbo'),
            'id'                => 'sticky_background_image',
            'type'              => 'background',
            'preview'           => false,
            'background-color'  => false,
            'output'            => array('.site-header .header-fixed .header-nav'),
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Sticky Header padding', 'wpbo'),
            'subtitle'          => esc_html__('Padding top and bottom', 'wpbo'),
            'id'                => 'sticky_header_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array( 'em', 'px', '%' ),
            'top'               => true,
            'right'             => false,
            'bottom'            => true,
            'left'              => false,
            'output'            => array( '.site-header .header-fixed .header-nav' ),
            'required'          => array( 'menu_sticky', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Typography', 'wpbo'),
            'subtitle'          => esc_html__('typography.', 'wpbo'),
            'id'                => 'sticky_header_logo_text_typography',
            'type'              => 'typography',
            'google'            => true,
            'text-align'        => false,
            'color'             => false,
            'output'            => array( 
                '.sticky_logo .site-title,.sticky_logo .site-title a' 
            ),
            'required'          => array( 'sticky_logo_type', '=', 'text' )
        ), 
    )
));

/**
 * Menu right icon
 *
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-minus',
    'title' => esc_html__('Menu right icon', 'wpbo'),
    'subsection' => true,
    'fields' => array(
        array(
            'title'             => esc_html__('Show Search', 'wpbo'),
            'id'                => 'hr_show_search',
            'type'              => 'switch',
            'default'           => true,
        ),
        array(
            'title'             => esc_html__('Show Cart', 'wpbo'),
            'id'                => 'hr_show_cart',
            'type'              => 'switch',
            'default'           => true,
        ),
        array(
            'id'                => 'hr_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Links Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select links color for icon', 'wpbo' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'default'   => array(
                'regular' => '',
                'hover'   => '',
            ),
            'output'            => array( '.navbar-right li > a,.header-style-2 .navbar-right li > a' ),
        ),
         
    )
));

/**
 * Page Title
 *
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Page Title & BC', 'wpbo'),
    'icon' => 'el-icon-map-marker',
    'fields' => array(
        array(
            'id'                => 'page_title_layout',
            'title'             => esc_html__('Layouts', 'wpbo'),
            'subtitle'          => esc_html__('select a layout for page title', 'wpbo'),
            'default'           => '7',
            'type'              => 'image_select',
            'options'           => array(
                                    '2' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-1.png',
                                    '3' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-2.png',
                                    '4' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-3.png',
                                    '5' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-4.png',
                                    '6' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-5.png',
                                    '7' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-6.png',
                                )
        ),
        array(
            'title'             => esc_html__('Is background overlay?', 'wpbo'),
            'id'                => 'page_title_is_overlay',
            'type'              => 'switch',
            'default'           => true,
        ),
        array(
            'id'                => 'page_title_background_overlay',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background overlay', 'wpbo' ),
            'default'   => array(
                'color' => '#363636',
                'alpha' => '0.5',
            ),
            'output'   => array(
                'background' => '.page-title .bg-overlay',
            ),
            'required'          => array( 'page_title_is_overlay', '=', 1 )
        ),
        
        array(
            'title'             => esc_html__('Background', 'wpbo'),
            'subtitle'          => esc_html__('Page title background.', 'wpbo'),
            'id'                => 'page_title_background',
            'type'              => 'background',
            'default'  => array(
                'background-color' => '',
                'background-repeat' => 'no-repeat',
                'background-size' => 'cover',
                'background-attachment' => 'scroll',
                'background-position' => 'top center',
                'background-image' => get_template_directory_uri().'/assets/images/pagetitle/page-title-bg.jpg',
            ),
            'output'            => array( '.page-title' )
        ),
        array(
            'title'             => esc_html__('Typography', 'wpbo'),
            'subtitle'          => esc_html__('Page title typography.', 'wpbo'),
            'id'                => 'page_title_typography',
            'type'              => 'typography',
            'google'            => true,
            'output'            => array( '.page-title #page-title-text h2' )
        ),
        
        array(
            'title'             => esc_html__('Padding', 'wpbo'),
            'subtitle'          => esc_html__('Page title padding (top/bottom).', 'wpbo'),
            'id'                => 'page_title_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array( 'em', 'px', '%' ),
            'top'               => true,
            'right'             => false,
            'bottom'            => true,
            'left'              => false,
            'output'            => array( '.page-title' )
        ),
        array(
            'id'        => 'page_title_align',
            'title'     => esc_html__('Align', 'wpbo'),
            'type'      => 'button_set',
            'options' => array(
                'text-left'     => esc_html__('Left','wpbo'), 
                'text-center'     => esc_html__('Center','wpbo'),
                'text-right'     => esc_html__('Right','wpbo'), 
            ), 
            'default'   => 'text-center',
            'required'          => array('page_title_layout','=',array('2','3','6','7'))
        ),
    )
));

/* Breadcrumb */
Redux::setSection($opt_name, array(
    'icon' => 'el-icon-random',
    'title' => esc_html__('Breadcrumb', 'wpbo'),
    'subsection' => true,
    'fields' => array(
        array(
            'title'             => esc_html__('Typography', 'wpbo'),
            'subtitle'          => esc_html__('Breadcrumb typography.', 'wpbo'),
            'id'                => 'breadcrumb_typography',
            'type'              => 'typography',
            'google'            => true,
            'output'            => array( '#page-title #breadcrumb-text' )
        ),
        array(
            'id'                => 'breadcrumb_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Link Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select link color in breadcrumb', 'wpbo' ),
            'output'            => array( '#page-title #breadcrumb-text ul li a' ),
        ),
    )
));

/**
 * Content
 *
 * css color.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Content', 'wpbo'),
    'icon' => 'el-icon-pencil',
    'fields' => array(
        array(
            'title'     => esc_html__('Padding', 'wpbo'),
            'subtitle'  => esc_html__('Choose padding for content tag', 'wpbo'),
            'id'        => 'content_padding',
            'type'      => 'spacing',
            'mode'      => 'padding',
            'right' => false,
            'left' => false,
            'units'     => array('px'),     
            'output'    => array('.site-content')
        ),
    )
));
/* page */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Page', 'wpbo'),
    'icon' => 'el-icon-list',
    'subsection' => true,
    'fields' => array(
        array(
            'subtitle'          => esc_html__('Show editor', 'wpbo'),
            'id'                => 'page_show_frontend_editor',
            'type'              => 'switch',
            'title'             => esc_html__('Frontend editor', 'wpbo'),
            'default'           => false,
        ),
    )
));
/* archive */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Archive', 'wpbo'),
    'icon' => 'el-icon-list',
    'subsection' => true,
    'fields' => array(
        array(
            'id'                => 'archive_layout',
            'title'             => esc_html__('Layouts', 'wpbo'),
            'subtitle'          => esc_html__('select a layout for archive, search, index...', 'wpbo'),
            'default'           => 'right',
            'type'              => 'image_select',
            'options'           => array(
                                        'left' => get_template_directory_uri().'/assets/images/content/right.png',
                                        'full' => get_template_directory_uri().'/assets/images/content/full.png',
                                        'right' => get_template_directory_uri().'/assets/images/content/left.png',
                                    )
        ),
        array(
            'subtitle' => esc_html__('Select the number of Blog columns to show on Blog page', 'wpbo'),
            'id' => 'blog_columns',
            'type' => 'select',
            'title' => esc_html__('Blog Columns', 'wpbo'),
            'options'=>array(
                'col-xs-12 col-sm-12 col-md-12 col-lg-12'=> esc_html__('1 Column','wpbo'),
                'col-xs-12 col-sm-6 col-md-6 col-lg-6'=> esc_html__('2 Columns','wpbo'),
                'col-xs-12 col-sm-6 col-md-4 col-lg-4'=> esc_html__('3 Columns','wpbo'),
            ),
            'default' => 'col-xs-12 col-sm-6 col-md-6 col-lg-6',
            'required'          => array( 'archive_layout', '=', array('left','right') )
        ),
        array(
            'subtitle' => esc_html__('Select the number of Blog columns to show on Blog page', 'wpbo'),
            'id' => 'blog_columns_full',
            'type' => 'select',
            'title' => esc_html__('Blog Columns', 'wpbo'),
            'options'=>array(
                'col-xs-12 col-sm-12 col-md-12 col-lg-12'=> esc_html__('1 Column','wpbo'),
                'col-xs-12 col-sm-6 col-md-6 col-lg-6'=> esc_html__('2 Columns','wpbo'),
                'col-xs-12 col-sm-6 col-md-4 col-lg-4'=> esc_html__('3 Columns','wpbo'),
                'col-xs-12 col-sm-6 col-md-4 col-lg-3'=> esc_html__('4 Columns','wpbo'),
            ),
            'default' => 'col-xs-12 col-sm-6 col-md-4 col-lg-4',
            'required'          => array( 'archive_layout', '=', 'full' )
        ),
        array(
            'subtitle'          => esc_html__('Excerpt length enter by ( number of word )', 'wpbo'),
            'id'                => 'excerpt_length',
            'type'              => 'text',
            'default'           => 18,
            'title'             => esc_html__('Excerpt length', 'wpbo'),
        ),
        array(
            'subtitle'          => esc_html__('Show author.', 'wpbo'),
            'id'                => 'archive_author',
            'type'              => 'switch',
            'title'             => esc_html__('Author', 'wpbo'),
            'default'           => false,
        ),
        array(
            'subtitle'          => esc_html__('Show categories.', 'wpbo'),
            'id'                => 'archive_categories',
            'type'              => 'switch',
            'title'             => esc_html__('Categories', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show tags.', 'wpbo'),
            'id'                => 'archive_tag',
            'type'              => 'switch',
            'title'             => esc_html__('Tags', 'wpbo'),
            'default'           => false,
        ),
        array(
            'subtitle'          => esc_html__('Show comment count.', 'wpbo'),
            'id'                => 'archive_comment',
            'type'              => 'switch',
            'title'             => esc_html__('Comment', 'wpbo'),
            'default'           => false,
        ),
        array(
            'subtitle'          => esc_html__('Show date time.', 'wpbo'),
            'id'                => 'archive_date',
            'type'              => 'switch',
            'title'             => esc_html__('Date', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show read more', 'wpbo'),
            'id'                => 'archive_read_more',
            'type'              => 'switch',
            'title'             => esc_html__('Read more', 'wpbo'),
            'default'           => true,
        )
    )
));

/* Single */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Single', 'wpbo'),
    'icon' => 'el-icon-file-edit',
    'subsection' => true,
    'fields' => array(
        array(
            'id'                => 'single_layout',
            'title'             => esc_html__('Layouts', 'wpbo'),
            'subtitle'          => esc_html__('select a layout for single...', 'wpbo'),
            'default'           => 'right',
            'type'              => 'image_select',
            'options'           => array(
                                        'left' => get_template_directory_uri().'/assets/images/content/right.png',
                                        'full' => get_template_directory_uri().'/assets/images/content/full.png',
                                        'right' => get_template_directory_uri().'/assets/images/content/left.png',
                                    )
        ),
        array(
            'subtitle'          => esc_html__('Show author.', 'wpbo'),
            'id'                => 'single_author',
            'type'              => 'switch',
            'title'             => esc_html__('Author', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show categories.', 'wpbo'),
            'id'                => 'single_categories',
            'type'              => 'switch',
            'title'             => esc_html__('Categories', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show tags.', 'wpbo'),
            'id'                => 'single_tag',
            'type'              => 'switch',
            'title'             => esc_html__('Tags', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show comment count.', 'wpbo'),
            'id'                => 'single_comment',
            'type'              => 'switch',
            'title'             => esc_html__('Comment', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show date time.', 'wpbo'),
            'id'                => 'single_date',
            'type'              => 'switch',
            'title'             => esc_html__('Date', 'wpbo'),
            'default'           => true,
        ),
        array(
            'title' => esc_html__('ENTRY FOOTER', 'wpbo'),
            'id'   => 'entry-footer-panel',
            'type' => 'info',
            'style' => 'success',
        ),
        array(
            'subtitle'          => esc_html__('Show tags.', 'wpbo'),
            'id'                => 'single_footer_tag',
            'type'              => 'switch',
            'title'             => esc_html__('Tags', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show social', 'wpbo'),
            'id'                => 'single_footer_social',
            'type'              => 'switch',
            'title'             => esc_html__('Tags', 'wpbo'),
            'default'           => true,
        ),
        array(
            'title' => esc_html__('POST NAVIGATION', 'wpbo'),
            'id'   => 'post-nav-panel',
            'type' => 'info',
            'style' => 'success',
        ),
        array(
            'subtitle'          => esc_html__('Show post navigation', 'wpbo'),
            'id'                => 'single_post_nav',
            'type'              => 'switch',
            'title'             => esc_html__('Post navigation', 'wpbo'),
            'default'           => false,
        ),
    )
));

/**
 * Portfolio
 *
 * css color.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Single portfolio', 'wpbo'),
    'icon' => 'el-icon-file-edit',
    'subsection' => true,
    'fields' => array(
        array(
            'title'             => esc_html__('Background', 'wpbo'),
            'subtitle'          => esc_html__('Page title background.', 'wpbo'),
            'id'                => 'port_title_background',
            'type'              => 'background',
            'default'  => array(
                'background-color' => '',
                'background-repeat' => 'no-repeat',
                'background-size' => 'cover',
                'background-attachment' => 'scroll',
                'background-position' => 'center center',
                'background-image' => get_template_directory_uri().'/assets/images/pagetitle/port-pagetitle-bg.jpg',
            ),
            'output'            => array( '.single-portfolio .page-title' )
        ),
        array(
            'subtitle'          => esc_html__('Show social sharing', 'wpbo'),
            'id'                => 'single_port_sharing',
            'type'              => 'switch',
            'title'             => esc_html__('Show social sharing', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show post navigation', 'wpbo'),
            'id'                => 'single_port_nav',
            'type'              => 'switch',
            'title'             => esc_html__('Show single portfolio navigation', 'wpbo'),
            'default'           => true,
        ),
        array(
            'subtitle'          => esc_html__('Show all portfolio', 'wpbo'),
            'id'                => 'single_port_show_all',
            'type'              => 'switch',
            'title'             => esc_html__('Show all portfolio', 'wpbo'),
            'default'           => true,
        ),
        array(
            'title'             => esc_html__('Enter Text', 'wpbo'),
            'subtitle'          => esc_html__('Enter text as (All Projects)', 'wpbo'),
            'id'                => 'single_port_show_all_text',
            'type'              => 'text',
            'required'          => array('single_port_show_all','=',1)
        ),
        array(
            'title'             => esc_html__('Enter URL', 'wpbo'),
            'subtitle'          => esc_html__('Enter url', 'wpbo'),
            'id'                => 'single_port_show_all_url',
            'type'              => 'text',
            'required'          => array('single_port_show_all','=',1)
        ),
    )
));
 
/**
 * Styling
 * 
 * css color.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Styling', 'wpbo'),
    'icon' => 'el-icon-adjust',
    'fields' => array(
        array(
            'subtitle' => esc_html__('Set color main color.', 'wpbo'),
            'id' => 'primary_color',
            'type' => 'color',
            'title' => esc_html__('Primary Color', 'wpbo'),
            'default' => '#2ecc71'
        ),
        array(
            'subtitle' => esc_html__('Set color second color.', 'wpbo'),
            'id' => 'second_color',
            'type' => 'color',
            'title' => esc_html__('Secondary Color', 'wpbo'),
            'default' => '#bdbdbd'
        ),
        array(
            'id'       => 'link_color',
            'type'     => 'link_color',
            'title'    => esc_html__( 'Links Color', 'wpbo' ),
            'subtitle' => esc_html__( 'Select Links Color Option', 'wpbo' ),
            'regular'   => true,
            'hover'     => true,
            'active'    => false,
            'visited'   => false,
            'default'           => array(
                'regular'           => '#363636',
                'hover'             => '#2ecc71',
            ),
            'output'   => array( 'a' ),
        ),
        array(
            'id'       => 'link_color_second',
            'type'     => 'link_color',
            'title'    => esc_html__( 'Second Links Color', 'wpbo' ),
            'subtitle' => esc_html__( 'Select Second Links Color Option', 'wpbo' ),
            'regular'   => true,
            'hover'     => true,
            'active'    => false,
            'visited'   => false,
            'default'           => array(
                'regular'           => '#bdbdbd',
                'hover'             => '#2ecc71',
            ),
        ),
         
    )
));

/**
 * Button
 * 
 * css color.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Button', 'wpbo'),
    'icon' => 'el el-hand-up',
    'fields' => array(
        array(
            'id' => 'btn_color',
            'type' => 'color',
            'title' => esc_html__('Color', 'wpbo'),
            'default' => '#fff'
        ),
        array(
            'id'                => 'btn_background',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background color', 'wpbo' ),
            'default'   => array(
                'color'     => '#2ecc71',
                'alpha'     => 1
            ),
        ),
        array(
            'id'                => 'btn_border_color',
            'type'              => 'color',
            'title'             => esc_html__( 'Border color', 'wpbo' ),
            'default' => '#2ecc71'
        ),
        array(
            'title' => esc_html__('BUTTON HOVER EFFECT', 'wpbo'),
            'id'   => 'btn-hover-panel',
            'type' => 'info',
            'style' => 'success',
        ), 
        array(
            'id' => 'btn_hover_color',
            'type' => 'color',
            'title' => esc_html__('Color', 'wpbo'),
            'default' => '#363636'
             
        ),
        array(
            'id'                => 'btn_hover_background',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background color', 'wpbo' ),
            'default'   => array(
                'color'     => 'transparent',
                'alpha'     => 0
            ),
        ),
        array(
            'id'                => 'btn_hover_border_color',
            'type'              => 'color',
            'title'             => esc_html__( 'Border color', 'wpbo' ),
            'default' => '#2ecc71'
        ),
    )
));


/**
 * coming soon option
 * 
 * extra css for customer.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Coming soon', 'wpbo'),
    'icon' => 'el el-exclamation-sign',
    'fields' => array(
         
        array(
            'title'             => esc_html__('Background', 'wpbo'),
            'subtitle'          => esc_html__('Page coming soon background.', 'wpbo'),
            'id'                => 'page_coming_soon_background',
            'type'              => 'background',
            'background-color'  => false,
            'output'            => array( 'body .coming-soon' )
        ),
        array(
            'title'             => esc_html__('Is background overlay?', 'wpbo'),
            'id'                => 'page_coming_soon_is_overlay',
            'type'              => 'switch',
            'default'           => true,
        ),
        array(
            'id'                => 'page_coming_soon_background_overlay',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background overlay', 'wpbo' ),
            'default'   => array(
                'color' => '#282828',
                'alpha' => '0.4',
                'rgba'  => 'rgb(40, 40, 40, 0.4)',
            ),
            'output'   => array(
                'background-color' => 'body .coming-soon .bg-overlay'
            ),
            'required'          => array( 'page_coming_soon_is_overlay', '=', 1 )
        ), 
    )
));

/**
 * Typography
 * 
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Typography', 'wpbo'),
    'icon' => 'el-icon-text-width',
    'fields' => array(
        array(
            'id' => 'font_body',
            'type' => 'typography',
            'title' => esc_html__('Body Font', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  => array('body'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'font-weight' => '400',
                'font-family' => 'Open Sans',
                'font-size' => '14px',
                'line-height' => '24px',
                'color' => '#999999',
                'google' => true,
            )
        ),
        array(
            'id' => 'font_h1',
            'type' => 'typography',
            'title' => esc_html__('H1', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'line-height'  => false,
            'output'  => array('h1'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'font-weight' => '500',
                'font-family' => 'Work Sans',
                'font-size' => '36px',
                'color' => '#363636',
            ) 
        ),
        array(
            'id' => 'font_h2',
            'type' => 'typography',
            'title' => esc_html__('H2', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'line-height'  => false,
            'output'  => array('h2'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'font-weight' => '500',
                'font-family' => 'Work Sans',
                'font-size' => '34px',
                'color' => '#363636',
            ) 
        ),
        array(
            'id' => 'font_h3',
            'type' => 'typography',
            'title' => esc_html__('H3', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'line-height'  => false,
            'output'  => array('h3'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'font-weight' => '500',
                'font-family' => 'Work Sans',
                'font-size' => '32px',
                'color' => '#363636',
            ) 
        ),
        array(
            'id' => 'font_h4',
            'type' => 'typography',
            'title' => esc_html__('H4', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'line-height'  => false,
            'output'  => array('h4'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'font-weight' => '500',
                'font-family' => 'Work Sans',
                'font-size' => '24px',
                'color' => '#363636',
            ) 
        ),
        array(
            'id' => 'font_h5',
            'type' => 'typography',
            'title' => esc_html__('H5', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'line-height'  => false,
            'output'  => array('h5'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'font-weight' => '500',
                'font-family' => 'Work Sans',
                'font-size' => '18px',
                'color' => '#363636',
            ) 
        ),
        array(
            'id' => 'font_h6',
            'type' => 'typography',
            'title' => esc_html__('H6', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'line-height'  => false,
            'output'  => array('h6'),
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'font-weight' => '500',
                'font-family' => 'Work Sans',
                'font-size' => '16px',
                'color' => '#363636',
            ) 
        )
    )
));

/**
 * Shop option
 * 
 * extra css for customer.
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Woocommerces', 'wpbo'),
    'icon' => 'el el-shopping-cart',
    'fields' => array(
       
        array(
            'id'                => 'woo_loop_layout',
            'title'             => esc_html__('Shop catalog layout', 'wpbo'),
            'subtitle'          => esc_html__('select a layout for catalog shop page', 'wpbo'),
            'default'           => 'left',
            'type'              => 'image_select',
            'options'           => array(
                                        'left' => get_template_directory_uri().'/assets/images/content/right.png',
                                        'full' => get_template_directory_uri().'/assets/images/content/full.png',
                                        'right' => get_template_directory_uri().'/assets/images/content/left.png',
                                    )
        ),
        array(
            'subtitle' => esc_html__('Select catalog product column', 'wpbo'),
            'id' => 'shop_columns',
            'type' => 'select',
            'title' => esc_html__('Products Columns', 'wpbo'),
            'options'=>array(
                'col-xs-12 col-sm-6 col-md-6'=> esc_html__('2 Columns','wpbo'),
                'col-xs-12 col-sm-6 col-md-4'=> esc_html__('3 Columns','wpbo'),
            ),
            'default' => 'col-xs-12 col-sm-6 col-md-4',
            'required'          => array( 'woo_loop_layout', '=', array('left','right') )
        ),
        array(
            'subtitle' => esc_html__('Select catalog product column', 'wpbo'),
            'id' => 'shop_columns_full',
            'type' => 'select',
            'title' => esc_html__('Products Columns', 'wpbo'),
            'options'=>array(
                'col-xs-12 col-sm-6 col-md-6'=> esc_html__('2 Columns','wpbo'),
                'col-xs-12 col-sm-6 col-md-4'=> esc_html__('3 Columns','wpbo'),
                'col-xs-12 col-sm-6 col-md-3'=> esc_html__('4 Columns','wpbo'),
            ),
            'default' => 'col-xs-12 col-sm-6 col-md-3',
            'required'          => array( 'woo_loop_layout', '=', 'full' )
        ),
        array(
            'subtitle' => esc_html__('Enter the number of products you want to show on catalog layout', 'wpbo'),
            'id' => 'shop_products',
            'type' => 'text',
            'title' => esc_html__('Number Product Per Page', 'wpbo'),
            'default' => '12',
        ),
        array(
            'id'                => 'woo_single_layout',
            'title'             => esc_html__('Product single layout', 'wpbo'),
            'subtitle'          => esc_html__('select a layout for single product page', 'wpbo'),
            'default'           => 'left',
            'type'              => 'image_select',
            'options'           => array(
                                        'left' => get_template_directory_uri().'/assets/images/content/right.png',
                                        'full' => get_template_directory_uri().'/assets/images/content/full.png',
                                        'right' => get_template_directory_uri().'/assets/images/content/left.png',
                                    )
        ),
        array(
            'title'             => esc_html__('Page title Background', 'wpbo'),
            'subtitle'          => esc_html__('Page title background.', 'wpbo'),
            'id'                => 'woo_page_title_background',
            'type'              => 'background',
            'default'  => array(
                'background-color' => '',
                'background-repeat' => 'no-repeat',
                'background-size' => 'cover',
                'background-attachment' => 'scroll',
                'background-position' => 'center center',
                'background-image' => get_template_directory_uri().'/assets/images/pagetitle/img64.jpg',
            ),
            'output'            => array( '.woocommerce .page-title' )
        ),
        
          
    )
));

/**
 * Social 
 * 
 * Lists individual social
 * @author Duong Tung
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Individual Socials', 'wpbo'),
    'icon' => 'el el-share',
    'fields' => array(
        array(
            'id'    => 'individual_social_info',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('Individual Socials Lists', 'wpbo'),
            'desc'  => esc_html__( 'Set link for social', 'wpbo'),
        ),
        array(
            'id' => 'facebook',
            'type' => 'text',
            'title' => esc_html__('Facebook Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'twitter',
            'type' => 'text',
            'title' => esc_html__('Twitter Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'rss',
            'type' => 'text',
            'title' => esc_html__('Rss Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'instagram',
            'type' => 'text',
            'title' => esc_html__('Instagram Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'google',
            'type' => 'text',
            'title' => esc_html__('Google Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'skype',
            'type' => 'text',
            'title' => esc_html__('Skype Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'linkedin',
            'type' => 'text',
            'title' => esc_html__('Linkedin', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'pinterest',
            'type' => 'text',
            'title' => esc_html__('Pinterest Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'vimeo',
            'type' => 'text',
            'title' => esc_html__('Vimeo Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'youtube',
            'type' => 'text',
            'title' => esc_html__('Youtube Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'yelp',
            'type' => 'text',
            'title' => esc_html__('Yelp Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'tumblr',
            'type' => 'text',
            'title' => esc_html__('Tumblr Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'behance',
            'type' => 'text',
            'title' => esc_html__('Behance Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
        array(
            'id' => 'dribbble',
            'type' => 'text',
            'title' => esc_html__('Dribbble Url', 'wpbo'),
            'subtitle' => '',
            'default' => '#'
        ),
         
        array(
            'id'    => 'individual_social_on_footer_info',
            'type'  => 'info',
            'style' => 'success',
            'title' => esc_html__('List social will show in footer', 'wpbo'),
        ),
        array(
            'id'      => 'individual_social_on_footer',
            'type'    => 'sorter',
            'title'   => 'Footer socials',
            'options' => array(
                'enabled'  => array(
                    'twitter'     => esc_html__('Twitter', 'wpbo'),
                    'facebook' => esc_html__('Facebook', 'wpbo'),
                    'dribbble' => esc_html__('Dribbble', 'wpbo'),
                    'pinterest' => esc_html__('Pinterest', 'wpbo'),
                ),
                'disabled' => array(
                    'youtube' => esc_html__('Youtube', 'wpbo'),
                    'linkedin'     => esc_html__('Linkedin', 'wpbo'),
                    'google' => esc_html__('Google', 'wpbo'),
                    'instagram' => esc_html__('Instagram', 'wpbo'),
                    'skype' => esc_html__('Skype', 'wpbo'),
                    'vimeo' => esc_html__('Vimeo', 'wpbo'),
                    'yelp' => esc_html__('Yelp', 'wpbo'),
                    'tumblr' => esc_html__('Tumblr', 'wpbo'),
                    'rss' => esc_html__('Rss', 'wpbo'),
                    'behance' => esc_html__('Behance', 'wpbo'),
                    
                )
            ),
        ),
         
 
    )
));

/* extra font. */
$custom_font_1 = Redux::getOption($opt_name, 'google-font-selector-1');
$custom_font_1 = !empty($custom_font_1) ? explode(',', $custom_font_1) : array();

Redux::setSection($opt_name, array(
    'title' => esc_html__('Extra Fonts', 'wpbo'),
    'icon' => 'el el-fontsize',
    'subsection' => true,
    'fields' => array(
        array(
            'id' => 'google-font-1',
            'type' => 'typography',
            'title' => esc_html__('Custom Font', 'wpbo'),
            'google' => true,
            'font-backup' => true,
            'all_styles' => true,
            'output'  =>  $custom_font_1,
            'units' => 'px',
            'subtitle' => esc_html__('Typography option with each property can be called individually.', 'wpbo'),
            'default' => array(
                'color' => '',
                'font-style' => '',
                'font-weight' => '',
                'font-family' => '',
                'google' => true,
                'font-size' => '',
                'line-height' => '',
                'text-align' => ''
            )
        ),
        array(
            'id' => 'google-font-selector-1',
            'type' => 'textarea',
            'title' => esc_html__('Selector 1', 'wpbo'),
            'subtitle' => esc_html__('add html tags ID or class (body,a,.class,#id)', 'wpbo'),
            'validate' => 'no_html',
            'default' => '',
        )
    )
));

/**
 * Footer
 *
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Footer', 'wpbo'),
    'icon' => 'el el-website',
    'fields' => array()
));

/* footer top. */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Footer Top', 'wpbo'),
    'icon' => 'el el-minus',
    'subsection' => true,
    'fields' => array(
        array(
            'title'     => esc_html__('Disable', 'wpbo'),
            'subtitle'  => esc_html__('Disable footer top', 'wpbo'),
            'id'        => 'disable_footer_top',
            'type'      => 'switch',
            'default'   => false
        ),
        array(
            'id'       => 'footer-top-column',
            'type'     => 'select',
            'title'    => esc_html__( 'Column', 'wpbo' ),
            'subtitle' => esc_html__( 'Select Footer Column', 'wpbo' ),
            'default'    => 3,
            'options'  => array(
                1 => esc_html__('1', 'wpbo' ),
                2 => esc_html__('2', 'wpbo' ),
                3 => esc_html__('3', 'wpbo' ),
                4 => esc_html__('4', 'wpbo' ),
            ),
            'required'  => array('disable_footer_top','=',0)
        ),
        array(
            'id'                => 'footer_top_background_color',
            'type'              => 'color_rgba',
            'title'             => esc_html__( 'Background color overlay', 'wpbo' ),
            'output'   => array(
                'background-color' => 'footer #footer-top .bg-overlay'
            ),
            'required'  => array('disable_footer_top','=',0)
        ),
        
        array(
            'title'             => esc_html__('Background', 'wpbo'),
            'subtitle'          => esc_html__('Footer top background', 'wpbo'),
            'id'                => 'footer_top_background',
            'type'              => 'background',
            'output'            => array( 'footer #footer-top' ),
            'required'  => array('disable_footer_top','=',0)
        ),
         
        array(
            'title'             => esc_html__('Padding', 'wpbo'),
            'subtitle'          => esc_html__('Footer top padding (top/bottom).', 'wpbo'),
            'id'                => 'footer_top_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array('px'),
            'right'             => false,
            'left'              => false,
            'output'            => array( 'footer #footer-top' ),
            'required'  => array('disable_footer_top','=',0)
        ),
        array(
            'title'             => esc_html__('Logo Type', 'wpbo'),
            'subtitle'          => esc_html__('Image / Text.', 'wpbo'),
            'id'                => 'footer_logo_type',
            'type'              => 'button_set',
            'options'           => array(
                1 => esc_html__('Image', 'wpbo'),
                0 => esc_html__('Text', 'wpbo')
            ),
            'default'           => 0,
            'required'  => array('disable_footer_top','=',0)
        ),
        array(
            'title'             => esc_html__('Select Logo', 'wpbo'),
            'subtitle'          => esc_html__('Select an image file for your logo.', 'wpbo'),
            'id'                => 'footer_logo',
            'type'              => 'media',
            'url'               => true,
            'default'           => array(
                'url'=>get_template_directory_uri().'/assets/images/footer-logo.png'
            ),
            'required'          => array('footer_logo_type', '=', 1 )
        ),
        array(
            'subtitle'          => esc_html__('Set max height for logo.', 'wpbo'),
            'id'                => 'logo_max_height',
            'type'              => 'dimensions',
            'units'             => array('px'),
            'width'             => false,
            'title'             => esc_html__('Logo Max Height', 'wpbo'),
            'required'          => array('footer_logo_type', '=', 1 )
        ),
        array(
            'title'             => esc_html__('Footer logo url', 'wpbo'),
            'subtitle'          => esc_html__('Enter the other url, if empty then use site home url', 'wpbo'),
            'id'                => 'footer_logo_url',
            'type'              => 'text',
            'required'          => array('disable_footer_top','=',0)
        ),
        array(
            'subtitle'          => esc_html__('Add custom logo text.', 'wpbo'),
            'id'                => 'footer_logo_text',
            'type'              => 'text',
            'title'             => esc_html__('Logo Text', 'wpbo'),
            'default'           => 'Bo.',
            'required'          => array( 'footer_logo_type', '=', 0 )
        ),
        array(
            'id'                => 'footer_logo_link_color',
            'type'              => 'link_color',
            'title'             => esc_html__( 'Logo Links Color', 'wpbo' ),
            'subtitle'          => esc_html__( 'Select links color for logo', 'wpbo' ),
            'regular'           => true,
            'hover'             => true,
            'active'            => false,
            'visited'           => false,
            'output'            => array( '.footer-top .site-title a' ),
            'required'          => array( 'footer_logo_type', '=', 0 )
        ),
        array(
            'subtitle' => esc_html__('Title color.', 'wpbo'),
            'id' => 'footer_top_title_color',
            'type' => 'color',
            'title' => esc_html__('Title Color', 'wpbo'),
            'output'    => array('.footer-top .wg-title','.footer-top h1','.footer-top h2','.footer-top h3','.footer-top h4','.footer-top h5','.footer-top h6'),
            'required'          => array('disable_footer_top','=',0)
        ),
        array(
            'subtitle' => esc_html__('Text color.', 'wpbo'),
            'id' => 'footer_top_text_color',
            'type' => 'color',
            'title' => esc_html__('Text Color', 'wpbo'),
            'output'    => array('.footer-top,.footer-top p,.footer-top .widget_text'),
            'required'          => array('disable_footer_top','=',0)
        ),
         
        array(
            'id'       => 'footer_top_link_color',
            'type'     => 'link_color',
            'title'    => esc_html__( 'Links Color', 'wpbo' ),
            'subtitle' => esc_html__( 'Select Links Color Option', 'wpbo' ),
            'regular'   => true,
            'hover'     => true,
            'active'    => false,
            'visited'   => false,
            'output'   => array( '.footer-top a,.footer-top ul li a' ),
            'required'          => array('disable_footer_top','=',0)
        ),
        array(
            'id'       => 'footer_top_icon_color',
            'type'     => 'link_color',
            'title'    => esc_html__( 'Icon Color', 'wpbo' ),
            'subtitle' => esc_html__( 'Select Icon Color Option', 'wpbo' ),
            'regular'   => true,
            'hover'     => true,
            'active'    => false,
            'visited'   => false,
            'output'   => array( '.footer-top i,.footer-top .social-indiv-inner li a,.footer-top .social-indiv-inner li a i' ),
            'required'          => array('disable_footer_top','=',0)
        ),
    )
));

/* footer bottom. */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Footer Bottom', 'wpbo'),
    'icon' => 'el el-minus',
    'subsection' => true,
    'fields' => array(
        array(
            'id'       => 'footer-bottom-column',
            'type'     => 'select',
            'title'    => esc_html__( 'Column', 'wpbo' ),
            'subtitle' => esc_html__( 'Select Footer Column', 'wpbo' ),
            'default'    => 2,
            'options'  => array(
                1 => esc_html__('1', 'wpbo' ),
                2 => esc_html__('2', 'wpbo' ),
                3 => esc_html__('3', 'wpbo' ),
                4 => esc_html__('4', 'wpbo' ),
            )
        ),
        array(
            'title'             => esc_html__('Background', 'wpbo'),
            'subtitle'          => esc_html__('Footer top background.', 'wpbo'),
            'id'                => 'footer_bottom_background',
            'type'              => 'background',
            'output'            => array( 'footer #footer-bottom' )
        ),
        array(
            'id'       => 'footer_bottom_link_color',
            'type'     => 'link_color',
            'title'    => esc_html__( 'Links Color', 'wpbo' ),
            'subtitle' => esc_html__( 'Select Links Color Option', 'wpbo' ),
            'regular'   => true,
            'hover'     => true,
            'active'    => false,
            'visited'   => false,
            'output'   => array( '.footer-bottom a,.footer-bottom ul li a' ),
        ),
        array(
            'subtitle' => esc_html__('Text color.', 'wpbo'),
            'id' => 'footer_bottom_text_color',
            'type' => 'color',
            'title' => esc_html__('Text Color', 'wpbo'),
            'output'    => array('.footer-bottom,.footer-bottom p')
        ),
        array(
            'title'             => esc_html__('Padding', 'wpbo'),
            'subtitle'          => esc_html__('Footer top padding (top/bottom).', 'wpbo'),
            'id'                => 'footer_bottom_padding',
            'type'              => 'spacing',
            'mode'              => 'padding',
            'units'             => array('px'),
            'right'             => false,
            'left'              => false,
            'output'            => array( 'footer #footer-bottom' )
        )
    )
));

/**
 * Optimal Core
 * 
 * Optimal options for theme. optimal speed
 * @author Fox
 */
Redux::setSection($opt_name, array(
    'title' => esc_html__('Optimal Core', 'wpbo'),
    'icon' => 'el-icon-idea',
    'fields' => array(
        array(
            'subtitle' => esc_html__('no minimize , generate css over time...', 'wpbo'),
            'id' => 'dev_mode',
            'type' => 'switch',
            'title' => esc_html__('Dev Mode (not recommended)', 'wpbo'),
            'default' => false
        )
    )
));