<?php
/**
 * Meta box config file
 */
if (! class_exists('MetaFramework')) {
    return;
}

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name' => apply_filters('opt_meta', 'opt_meta_options'),
    // Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    // Allow you to start the panel in an expanded way initially.
    'open_expanded' => false,
    // Disable the save warning when a user changes a field
    'disable_save_warn' => true,
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => false,

    'output' => false,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => false,
    // Show the time the page took to load, etc
    'update_notice' => false,
    // 'disable_google_fonts_link' => true, // Disable this in case you want to create your own google fonts loader
    'admin_bar' => false,
    // Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => false,
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => false,
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => false,
    // save meta to multiple keys.
    'meta_mode' => 'multiple'
);

// -> Set Option To Panel.
MetaFramework::setArgs($args);

add_action('admin_init', 'bo_meta_boxs');

MetaFramework::init();

function bo_meta_boxs()
{

    /** page options */
    MetaFramework::setMetabox(array(
        'id' => '_page_main_options',
        'label' => esc_html__('Page Setting', 'wpbo'),
        'post_type' => 'page',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => false,
        'sections' => array(
            array(
                'title' => esc_html__('Header', 'wpbo'),
                'id' => 'tab-page-header',
                'icon' => 'el el-credit-card',
                'fields' => array(
                    array(
                        'subtitle' => esc_html__('Header transparent', 'wpbo'),
                        'id' => 'header_transparent',
                        'type' => 'switch',
                        'title' => esc_html__('Header transparent', 'wpbo'),
                        'default' => false,
                    ),  
                    array(
                        'subtitle' => esc_html__('Show border bottom', 'wpbo'),
                        'id' => 'border_bottom',
                        'type' => 'switch',
                        'title' => esc_html__('Border bottom', 'wpbo'),
                        'default' => false,
                        'required' => array( 0 => 'header_transparent', 1 => '=', 2 => 1 )
                    ),
                    array(
                        'id' => 'header_menu',
                        'type' => 'select',
                        'title' => esc_html__('Select Menu', 'wpbo'),
                        'subtitle' => esc_html__('custom menu for current page', 'wpbo'),
                        'options' => bo_get_nav_menu(),
                        'default' => '',
                    ),
                )
            ),
            array(
                'title' => esc_html__('Page Title & BC', 'wpbo'),
                'id' => 'tab-page-title-bc',
                'icon' => 'el el-map-marker',
                'fields' => array(
                    array(
                        'subtitle' => esc_html__('Disable Page title for current page.', 'wpbo'),
                        'id' => 'disable_page_title',
                        'type' => 'switch',
                        'title' => esc_html__('Disable', 'wpbo'),
                        'default' => false,
                    ),
                    array(
                        'id' => 'page_title_layout',
                        'title' => esc_html__('Layouts', 'wpbo'),
                        'subtitle' => esc_html__('select a layout for page title', 'wpbo'),
                        'default' => '',
                        'type' => 'image_select',
                        'options' => array(
                            '' => get_template_directory_uri() . '/assets/images/pagetitle/pt-s-default.png',
                            '2' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-1.png',
                            '3' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-2.png',
                            '4' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-3.png',
                            '5' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-4.png',
                            '6' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-5.png',
                            '7' => get_template_directory_uri().'/assets/images/pagetitle/pt-s-6.png',
                        ),
                        'required' => array( 0 => 'disable_page_title', 1 => '=', 2 => 0 )
                    ),
                    array(
                        'id' => 'page_title_text',
                        'type' => 'text',
                        'title' => esc_html__('Custom Title', 'wpbo'),
                        'subtitle' => esc_html__('Custom current page title.', 'wpbo'),
                        'required' => array( 0 => 'disable_page_title', 1 => '=', 2 => 0 )
                    ),
                    array(
                        'title'             => esc_html__('Background', 'wpbo'),
                        'subtitle'          => esc_html__('Page title background.', 'wpbo'),
                        'id'                => 'page_title_background',
                        'type'              => 'background',
                        'required' => array( 0 => 'disable_page_title', 1 => '=', 2 => 0 )
                    ),
                    array(
                        'title'     => esc_html__('Padding', 'wpbo'),
                        'subtitle'  => esc_html__('Choose padding for page title', 'wpbo'),
                        'id'        => 'page_title_padding',
                        'type'      => 'spacing',
                        'mode'      => 'padding',
                        'right' => false,
                        'left' => false,
                        'units'     => array('px'),     
                        'required' => array( 0 => 'disable_page_title', 1 => '=', 2 => 0 )
                    ),
                )
            ),
            array(
                'title' => esc_html__('Content', 'wpbo'),
                'id' => 'tab-content',
                'icon' => 'el el-pencil',
                'fields' => array(
                    array(
                        'title'     => esc_html__('Padding', 'wpbo'),
                        'subtitle'  => esc_html__('Choose padding for content tag', 'wpbo'),
                        'id'        => 'content_padding',
                        'type'      => 'spacing',
                        'mode'      => 'padding',
                        'right' => false,
                        'left' => false,
                        'units'     => array('px'),     
                    ),
                    array(
                        'subtitle' => esc_html__('White background', 'wpbo'),
                        'id' => 'white_bg',
                        'type' => 'switch',
                        'title' => esc_html__('White background', 'wpbo'),
                        'default' => false,
                    )
                )
            )
              
        )
    ));

    /** post options */
    MetaFramework::setMetabox(array(
        'id' => '_page_post_format_options',
        'label' => esc_html__('Post Format', 'wpbo'),
        'post_type' => 'post',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => true,
        'sections' => array(
            array(
                'title' => '',
                'id' => 'color-Color',
                'icon' => 'el el-laptop',
                'fields' => array(
                    array(
                        'id' => 'opt-video-type',
                        'type' => 'select',
                        'title' => esc_html__('Select Video Type', 'wpbo'),
                        'subtitle' => esc_html__('Local video, Youtube, Vimeo', 'wpbo'),
                        'options' => array(
                            'local' => esc_html__('Upload', 'wpbo'),
                            'youtube' => esc_html__('Youtube', 'wpbo'),
                            'vimeo' => esc_html__('Vimeo', 'wpbo'),
                        )
                    ),
                    array(
                        'id' => 'otp-video-local',
                        'type' => 'media',
                        'url' => true,
                        'mode' => false,
                        'title' => esc_html__('Local Video', 'wpbo'),
                        'subtitle' => esc_html__('Upload video media using the WordPress native uploader', 'wpbo'),
                        'required' => array('opt-video-type', '=', 'local')
                    ),
                    array(
                        'id' => 'opt-video-youtube',
                        'type' => 'text',
                        'title' => esc_html__('Youtube', 'wpbo'),
                        'subtitle' => esc_html__('Load video from Youtube.', 'wpbo'),
                        'placeholder' => esc_html__('https://youtu.be/iNJdPyoqt8U', 'wpbo'),
                        'required' => array('opt-video-type', '=', 'youtube')
                    ),
                    array(
                        'id' => 'opt-video-vimeo',
                        'type' => 'text',
                        'title' => esc_html__('Vimeo', 'wpbo'),
                        'subtitle' => esc_html__('Load video from Vimeo.', 'wpbo'),
                        'placeholder' => esc_html__('https://vimeo.com/155673893', 'wpbo'),
                        'required' => array('opt-video-type', '=', 'vimeo')
                    ),
                    array(
                        'id' => 'otp-video-thumb',
                        'type' => 'media',
                        'url' => true,
                        'mode' => false,
                        'title' => esc_html__('Video Thumb', 'wpbo'),
                        'subtitle' => esc_html__('Upload thumb media using the WordPress native uploader', 'wpbo'),
                        'required' => array('opt-video-type', '=', 'local')
                    ),
                    array(
                        'id' => 'otp-audio',
                        'type' => 'media',
                        'url' => true,
                        'mode' => false,
                        'title' => esc_html__('Audio Media', 'wpbo'),
                        'subtitle' => esc_html__('Upload audio media using the WordPress native uploader', 'wpbo'),
                    ),
                    array(
                        'id' => 'opt-gallery',
                        'type' => 'gallery',
                        'title' => esc_html__('Add/Edit Gallery', 'wpbo'),
                        'subtitle' => esc_html__('Create a new Gallery by selecting existing or uploading new images using the WordPress native uploader', 'wpbo'),
                    ),
                    array(
                        'id' => 'opt-quote-title',
                        'type' => 'text',
                        'title' => esc_html__('Quote Title', 'wpbo'),
                        'subtitle' => esc_html__('Quote title or quote name...', 'wpbo'),
                    ),
                    array(
                        'id' => 'opt-quote-content',
                        'type' => 'textarea',
                        'title' => esc_html__('Quote Content', 'wpbo'),
                    ),
                )
            ),
        )
    ));
     /** Portfolio options */
    MetaFramework::setMetabox(array(
        'id' => '_page_portfolio_format_options',
        'label' => esc_html__('Portfolio Option', 'wpbo'),
        'post_type' => 'portfolio',
        'context' => 'advanced',
        'priority' => 'default',
        'open_expanded' => true,
        'sections' => array(
            array(
                'title' => '',
                'id' => 'color-Color',
                'icon' => 'el el-laptop',
                'fields' => array(
                    array(
                        'id'       => 'opt_port_gallery',
                        'type'     => 'gallery',
                        'title'    => esc_html__('Add/Edit Gallery', 'wpbo'),
                        'subtitle' => esc_html__('Create a new Gallery by selecting existing or uploading new images using the WordPress native uploader', 'wpbo'),
                    ),
                )
            ),
             
        )
    ));
}